@@ -21,6 +21,7 @@ package org.apache.maven.shared.dependency.graph.internal;
 
 import org.apache.maven.artifact.resolver.filter.ArtifactFilter;
 import org.apache.maven.project.MavenProject;
+import org.apache.maven.project.ProjectBuildingRequest;
 import org.apache.maven.shared.dependency.graph.DependencyGraphBuilder;
 import org.apache.maven.shared.dependency.graph.DependencyGraphBuilderException;
 import org.apache.maven.shared.dependency.graph.DependencyNode;
@@ -33,12 +34,14 @@ import org.codehaus.plexus.context.ContextException;
 import org.codehaus.plexus.logging.AbstractLogEnabled;
 import org.codehaus.plexus.personality.plexus.lifecycle.phase.Contextualizable;
 
+import java.util.Collection;
+
 /**
- * Default dependency graph builder that detects current Maven version to delegate to either
- * Maven 2 or Maven 3 specific code.
+ * Default dependency graph builder that detects current Maven version to delegate to either Maven 3.0 or 3.1+ specific
+ * code.
  *
- * @see Maven2DependencyGraphBuilder
  * @see Maven3DependencyGraphBuilder
+ * @see Maven31DependencyGraphBuilder
  * @author Hervé Boutemy
  * @since 2.0
  */
@@ -49,18 +52,50 @@ public class DefaultDependencyGraphBuilder
 {
     protected PlexusContainer container;
 
-    public DependencyNode buildDependencyGraph( MavenProject project, ArtifactFilter filter )
+    /**
+     * Builds a dependency graph.
+     *
+     * @param buildingRequest the buildingRequest
+     * @param filter artifact filter (can be <code>null</code>)
+     * @return DependencyNode containing the dependency graph.
+     * @throws DependencyGraphBuilderException if some of the dependencies could not be resolved.
+     */
+    @Override
+    public DependencyNode buildDependencyGraph( ProjectBuildingRequest buildingRequest, ArtifactFilter filter )
+        throws DependencyGraphBuilderException
+    {
+        return buildDependencyGraph( buildingRequest, filter, null );
+    }
+
+    /**
+     * Builds a dependency graph.
+     *
+     * @param filter artifact filter (can be <code>null</code>)
+     * @param reactorProjects Collection of those projects contained in the reactor (can be <code>null</code>)
+     * @return DependencyNode containing the dependency graph.
+     * @throws DependencyGraphBuilderException if some of the dependencies could not be resolved.
+     */
+    @Override
+    public DependencyNode buildDependencyGraph( ProjectBuildingRequest buildingRequest, ArtifactFilter filter,
+                                                Collection<MavenProject> reactorProjects )
         throws DependencyGraphBuilderException
     {
         try
         {
-            String hint = isMaven31() ? "maven31" : isMaven2x() ? "maven2" : "maven3";
-            getLogger().debug( "building " + hint + " dependency graph for " + project.getId() );
+            String hint = isMaven31() ? "maven31" : "maven3";
 
             DependencyGraphBuilder effectiveGraphBuilder =
                 (DependencyGraphBuilder) container.lookup( DependencyGraphBuilder.class.getCanonicalName(), hint );
+            
+            if ( getLogger().isDebugEnabled() )
+            {
+                MavenProject project = buildingRequest.getProject();
+                
+                getLogger().debug( "building " + hint + " dependency graph for " + project.getId() + " with "
+                                + effectiveGraphBuilder.getClass().getSimpleName() );
+            }
 
-            return effectiveGraphBuilder.buildDependencyGraph( project, filter );
+            return effectiveGraphBuilder.buildDependencyGraph( buildingRequest, filter, reactorProjects );
         }
         catch ( ComponentLookupException e )
         {
@@ -69,22 +104,14 @@ public class DefaultDependencyGraphBuilder
     }
 
     /**
-     * Check the current Maven version to see if it's Maven 2.x.
-     */
-    protected static boolean isMaven2x()
-    {
-        return !canFindCoreClass( "org.apache.maven.project.DependencyResolutionRequest" ); // Maven 3 specific
-    }
-
-    /**
-     * Check the current Maven version to see if it's Maven 3.1.
+     * @return true if the current Maven version is Maven 3.1.
      */
     protected static boolean isMaven31()
     {
         return canFindCoreClass( "org.eclipse.aether.artifact.Artifact" ); // Maven 3.1 specific
     }
 
-    private static boolean canFindCoreClass( String className)
+    private static boolean canFindCoreClass( String className )
     {
         try
         {
@@ -98,6 +125,13 @@ public class DefaultDependencyGraphBuilder
         }
     }
 
+    /**
+     * Injects the Plexus content.
+     *
+     * @param context   Plexus context to inject.
+     * @throws ContextException if the PlexusContainer could not be located.
+     */
+    @Override
     public void contextualize( Context context )
         throws ContextException
     {
